@@ -14,15 +14,14 @@
     *************************************************************************
 */
 
-
 #include "testbedaccount.h"
 
-#include <kaction.h>
+#include <QAction>
 #include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kactionmenu.h>
-#include <kmenu.h>
-#include <kicon.h>
+
+#include <QIcon>
 
 #include "kopetemetacontact.h"
 #include "kopetecontactlist.h"
@@ -31,7 +30,6 @@
 #include "testbedfakeserver.h"
 #include "testbedprotocol.h"
 
-
 TestbedAccount::TestbedAccount( TestbedProtocol *parent, const QString& accountID )
 : Kopete::Account ( parent, accountID )
 {
@@ -52,9 +50,9 @@ void TestbedAccount::fillActionMenu( KActionMenu *actionMenu )
 
 	actionMenu->addSeparator();
 
-	KAction *action;
+	QAction *action;
 
-	action = new KAction (KIcon("testbed_showvideo"), i18n ("Show my own video..."), actionMenu );
+    action = new QAction (QIcon::fromTheme(QStringLiteral("testbed_showvideo")), i18n ("Show my own video..."), actionMenu );
         //, "actionShowVideo");
 	QObject::connect( action, SIGNAL(triggered(bool)), this, SLOT(slotShowVideo()) );
 	actionMenu->addAction(action);
@@ -64,7 +62,7 @@ void TestbedAccount::fillActionMenu( KActionMenu *actionMenu )
 bool TestbedAccount::createContact(const QString& contactId, Kopete::MetaContact* parentContact)
 {
 	TestbedContact* newContact = new TestbedContact( this, contactId, parentContact );
-	return newContact != 0L;
+	return newContact != nullptr;
 }
 
 void TestbedAccount::setAway( bool away, const QString & /* reason */ )
@@ -151,7 +149,6 @@ void TestbedAccount::slotGoBusy ()
 	updateContactStatus();
 }
 
-
 void TestbedAccount::slotGoOffline ()
 {
 	kDebug ( 14210 ) ;
@@ -200,5 +197,3 @@ void TestbedAccount::updateContactStatus()
 	}
 }
 
-
-#include "testbedaccount.moc"
